Struct mockable::MockHttpServer
source · pub struct MockHttpServer { /* private fields */ }Expand description
Implementations
sourceimpl MockHttpServer
impl MockHttpServer
sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
sourceimpl MockHttpServer
impl MockHttpServer
sourcepub fn expect_next(&mut self) -> &mut Expectation
pub fn expect_next(&mut self) -> &mut Expectation
Create an Expectation for mocking the next method
sourcepub fn expect_stop(&mut self) -> &mut Expectation
pub fn expect_stop(&mut self) -> &mut Expectation
Create an Expectation for mocking the stop method